@@ -20,7 +20,7 @@ import itertools as it
 
 import numpy as np
 
-from ._base import RankResult, SKCDecisionMakerABC
+from ._madm_base import RankResult, SKCDecisionMakerABC
 from ..core import Objective
 from ..utils import doc_inherit, rank
 
